pro ppt_compare_polcats, Event
;
;	combines the information contained in polcats back into one polcat
;
;	this version picks the matching star with the lowest sP
;
;	20111229 DPC
;	20120927  revisited
;	20130207  added switches for headers and S/N cuts
;   20200117  imported into MSP_PPT and trimmed
;
;
WIDGET_CONTROL, Event.top, GET_UVALUE=PTR
;
fscale = 1000000L
match_window 	= 2.0d0			; arcsec
mag_window 		= 2.0d0			; magnitudes
;-------------------------------------------------------------------
;
save_headers = 1
;
save_all = 1
;
file_out = (*PTR).file_out
;
openw, lu_out, file_out, /GET_LUN
;
polcat_paths = (*PTR).polcat_compares[0:((*PTR).n_polcat_compares - 1)]
;
nfiles = N_ELEMENTS(polcat_paths)
;
;	get all the polcat structures
;
pst_ptr = PTRARR(nfiles)
;
;	put comments in about the file origin
;
printf, lu_out, ';;Combined (best selected) POLCAT file generated by MSP_PPT'
printf, lu_out, ';;on '+SYSTIME()
printf, lu_out, ';;...'
;
for ifile = 0, nfiles-1 do begin
	;
	;	test each POLCAT and read correct type
	;
	(*PTR).analysis_polcat_path = polcat_paths[ifile]
	test_polcat_type,Event
	if((*PTR).is_polcat_flag eq 1) then begin
		;
		pst_ptr[ifile] =  PTR_NEW(PPT_Read_POLCAT(polcat_paths[ifile]))
		;
	endif
	if((*PTR).is_merged_flag eq 1) then begin
				;
				pst_ptr[ifile] =  PTR_NEW(PPT_Read_merged_POLCAT(polcat_paths[ifile]))
				;
	endif
	;
	zprint,Event,'For file '+FILE_BASENAME(polcat_paths[ifile])+' read '+$
			string(N_ELEMENTS((*pst_ptr[ifile]).s[*].RA_deg),format='(I)')+' lines from POLCAT'
	;
	;	and add key quantities to some arrays
	;
	if(ifile eq 0) then begin
		ra = (*pst_ptr[ifile]).s[*].RA_deg
		dec = (*pst_ptr[ifile]).s[*].Dec_deg
		num = (*pst_ptr[ifile]).s[*].num + ifile * fscale
		mag = (*pst_ptr[ifile]).s[*].H_mag
	endif else begin
		ra = [ra, (*pst_ptr[ifile]).s[*].RA_deg]
		dec = [dec, (*pst_ptr[ifile]).s[*].Dec_deg]
		num = [num, (*pst_ptr[ifile]).s[*].num + ifile * fscale]
		mag = [mag, (*pst_ptr[ifile]).s[*].H_mag]
	endelse
	;
	;	if save_headers = 1, copy the input header to the output file
	;
	if(save_headers eq 1) then begin
		printf, lu_out, ifile+1, nfiles, FILE_BASENAME(polcat_paths[ifile]),$
				format='(";;POLCAT Header ",i2," of ",i2," from ",a)'
		openr, lu_in, polcat_paths[ifile],/GET_LUN
		WHILE ~EOF(lu_in) do begin
			line = ''
			readf, lu_in, line, format='(a)'
			ind = STRPOS(line,';;')
			if(ind eq 0) then begin
				;
				;	only copy lines without | or space in next character
				;
				jnd = STRPOS(line,'|',2)
				knd = STRPOS(line,' ',2)
				if(jnd ne 2 and knd ne 2) then printf, lu_out, line, format='(a)'
			endif
		ENDWHILE
		FREE_LUN, lu_in
	endif
endfor
;
;	collect all the data entries into one, big list
;
; RA, Dec in decimal degrees
;
nlines = long(N_ELEMENTS(ra))
zprint,Event, 'read in a total of '+String(nlines,format='(I)')+' lines'
;
;	sort by magnitude - brightest to faintest - bias to bright stars matching first
;
ind_mag = SORT(mag)
;
ra = ra[ind_mag]
dec = dec[ind_mag]
mag = mag[ind_mag]
num = num[ind_mag]
;
;	label each entry
;
gflag = lonarr(nlines)
;
;	for each entry, find neighbors and classify
;
igroup = 1L
pwindow = match_window * 2.77778d-4		; match_window arcsec radius
;
n1_stars = 0L
n2_stars = 0L
;
test_ind = lindgen(nlines)
;
for i = 0L, nlines-1L do begin
	if(gflag[i] eq 0) then begin
		;
		mflag = 0L
		;
		this_ra 	= ra[i]
		this_dec 	= dec[i]
		this_mag 	= mag[i]
		this_num 	= num[i]
		;
		gflag[i] = igroup
		;
		;	find nearest that isn't this one and hasn't already been selected
		;
		;	and is in the magnitude window and isn't in its own file
		;
		ind = WHERE(test_ind ne i 	and $
				    gflag eq 0L 	and $
				    abs(this_mag - mag) le mag_window and $
				    abs(this_num - num) gt fscale/10,n_ok)
		if(n_ok gt 0) then begin
			;
			;	then, find the minimum distance of the survivors
			;
			dra = this_ra - ra[ind]
			ddec = this_dec - dec[ind]
			;
			;	correct for cos(dec) in dra
			;
			cosd = cos(this_dec*1.74533d-2)
			dra *= cosd
			;
			dd = sqrt((dra*dra) + (ddec * ddec))
			dm = abs(this_mag - mag[ind])
			;
			;	identify all the candidates within the matching window
			;
			jnd = WHERE(dd le pwindow,n_can)		; jnd points to within ind
			;
			if(n_can gt 0) then begin
				;
				;	find the smallest distance candidate for each file
				;		- only allow one per file
				;
				;	how many stars from each file?
				;
				this_file = FLOOR(this_num / fscale)
				n_stars_to_test = intarr(nfiles)
				n_stars_to_test[this_file] = -1
				;
				these_files = FLOOR(num[ind[jnd]] / fscale)
				for kk = 0L, nfiles-1L do begin
					ll = WHERE(these_files eq kk,n)
					if(kk ne this_file) then begin
						n_stars_to_test[kk] = n
					endif
				endfor
				;
				for kk = 0, nfiles-1 do begin
					if(n_stars_to_test[kk] gt 0) then begin
						;
						;	among those stars, find the one with the smallest
						;	distance and the closest magnitude
						;
						ind_f = WHERE(these_files eq kk,nf)
						;
						if(nf eq 0) then stop
						;
						merit = dd[jnd[ind_f]] + dm[jnd[ind_f]]	; 0.1 " same as 0.1 mag
						;
						dmin = MIN(merit,fdd)
						;
						j = ind[jnd[ind_f[fdd]]]
						;
						;	found a match
						;
						gflag[j] = gflag[i]		; collect this star into this group
						mflag = 1L				; set flag that says we got at least one match
					endif
				endfor
			endif				; if no candidates in the distance offset window, then don't set the match flag
		endif					; if no candidates in the mag and file windows, then don't set match flag
		;
		igroup++				; whether we matched or not, bump the group counter if the star wasn't previously matched
		;
		;	was the star matched, or not?
		;
		if(mflag eq 0L) then n1_stars++ else n2_stars++
		;
	endif						; if this star already assigned to a group, don't consider it again
endfor
;
;	all groups made, start processing
;
ngroups = igroup-1L
;
zprint,Event,'Number of single stars unmatched = '+string(n1_stars,format='(I)')
zprint,Event,'Number of stars that matched to others = '+string(n2_stars,format='(I)')
zprint,Event,'Number of single stars plus matched star groups = '+string(ngroups,format='(I)')
;
;stop
;
;	for each group
;
nstr = 0
str = ';;  Num. RA[J2000]   Dec[J2000] H(Mimir)  sH      P[%]  sP[%] PA[deg]  sPA '+$
				'     Q[%]   sQ[%]     U[%]   sU[%] N   Desig(2MASS)     J_2   sJ_2  '+$
				'  H_2   sH_2    K_2   sK_2   (H-K) s(H-K) 3.6mag  s3.6m 4.5mag  '+$
				's4.5m 5.8mag  s5.8m 8.0mag  s8.0m'
;
nout = 0L
;
n1_reject = 0L
n2_reject = 0L
;
n_unique = 0L
n_common = 0L
;
;	sort groups by increasing RA
;
ra_group = dblarr(ngroups)
;
for ig = 1L, ngroups do begin
	ind = WHERE(gflag eq ig, ng)
	ra_group[ig-1] = ra[ind[0]]
endfor
;
ind_s_ra = SORT(ra_group) + 1L

for iig = 1L, ngroups do begin
	;
	ig = ind_s_ra[iig-1]
	;
	;	which entries
	;
	ind = WHERE(gflag eq ig, ng)
	;
	if(ng eq 0) then begin
		zprint,Event,'Eh? For Group '+string(ig,format='(I)')+' no entries... stopping.'
		stop
	endif
	;
	;	if just 1 entry, put it in output file
	;
	fmt1 = '(I5.5,1x,D12.6,1x,D12.6,1x,F7.3,1x,f6.3,1x,f7.3,1x,f6.3,1x,f6.1,1x,f6.1,1x'
	fmt2 = ',2(f8.3,1x,f7.3,1x),i1,1x,a16,1x,3(f6.3,1x,f6.3,1x),f6.3,1x,f6.3,1x,'
	fmt3 = '8(f6.3,1x))'
	;
	fmt = fmt1+fmt2+fmt3
	;
	if(ng eq 1) then begin
		;
		if(nstr eq 0) then begin
;			file_out = dialog_pickfile(Title='Output File')
;			openw, lu_out, file_out, /GET_LUN
			printf, lu_out, str, format='(a)'
			nstr++
		endif
			;
		k = num(ind[0])
		;
		;	get file, entry number
		;
		kfile = FLOOR(k / fscale)
		;
		kk = k - fscale * kfile -1
		;
		n = 1
		;
		;	if SNR > 2.5 or sP < 0.5% and P < 15%, write *** 20200117 - keep all - will cut in later code (DPC)
		;
		HK = (*pst_ptr[kfile]).s[kk].H_2mass - (*pst_ptr[kfile]).s[kk].K_2mass
		sHK = (sqrt( ((*pst_ptr[kfile]).s[kk].sK2mass^2) + ((*pst_ptr[kfile]).s[kk].sH2mass^2))) < 99.99
		this_P = (*pst_ptr[kfile]).s[kk].P
		this_sP = (*pst_ptr[kfile]).s[kk].sP
		;
;		if(((this_P/this_sP ge snr_limit or this_sP le sp_limit) $
;					and (this_P lt p_limit)) or save_all eq 1) then begin

			this_str = STRING(iig,(*pst_ptr[kfile]).s[kk].RA_deg,(*pst_ptr[kfile]).s[kk].Dec_deg,$
				(*pst_ptr[kfile]).s[kk].H_mag,(*pst_ptr[kfile]).s[kk].sHmag,$
				(*pst_ptr[kfile]).s[kk].P,(*pst_ptr[kfile]).s[kk].sP,$
				(*pst_ptr[kfile]).s[kk].PA_deg,(*pst_ptr[kfile]).s[kk].sPA,$
				(*pst_ptr[kfile]).s[kk].Q,(*pst_ptr[kfile]).s[kk].sQ,$
				(*pst_ptr[kfile]).s[kk].U,(*pst_ptr[kfile]).s[kk].sU,n,$
				(*pst_ptr[kfile]).s[kk].desig_2mass,(*pst_ptr[kfile]).s[kk].J_2mass,$
				(*pst_ptr[kfile]).s[kk].sJ2mass,(*pst_ptr[kfile]).s[kk].H_2mass,$
				(*pst_ptr[kfile]).s[kk].sH2mass,(*pst_ptr[kfile]).s[kk].K_2mass,$
				(*pst_ptr[kfile]).s[kk].sK2mass,HK,sHK,$
				(*pst_ptr[kfile]).s[kk].b36mag,$
				(*pst_ptr[kfile]).s[kk].e_b36mag,$
				(*pst_ptr[kfile]).s[kk].b45mag,$
				(*pst_ptr[kfile]).s[kk].e_b45mag,$
				(*pst_ptr[kfile]).s[kk].b58mag,$
				(*pst_ptr[kfile]).s[kk].e_b58mag,$
				(*pst_ptr[kfile]).s[kk].b80mag,$
				(*pst_ptr[kfile]).s[kk].e_b80mag,$
				format=fmt)
			printf, lu_out, this_str, format='(a)'
			nout++
			n_unique++
		;endif else n1_reject++
	endif else begin
		;
		;	> 1 entry, compute mean properties, with weighting
		;
		;	unless too bright, then skip deeper obs
		if(nstr eq 0) then begin
			printf, lu_out, str, format='(a)'
			nstr++
		endif
		;
		;	compute mean Q, U properties
		;
		kf = num(ind[0])		; the first one
		;
		;	get file, entry number for first
		;
		kfile = FLOOR(kf / fscale)
		;
		kk = kf - fscale * kfile -1
		;
		;	and all the rest
		;
		Q = dblarr(ng)
		sQ = dblarr(ng)
		U = dblarr(ng)
		sU = dblarr(ng)
		;
		for ifile = 0L, ng-1L do begin
			jfile = FLOOR(num(ind[ifile]) / fscale)
			jj = num(ind[ifile]) - fscale * jfile - 1
			;
			Q[ifile] = (*pst_ptr[jfile]).s[jj].Q
			sQ[ifile] = (*pst_ptr[jfile]).s[jj].sQ
			U[ifile] = (*pst_ptr[jfile]).s[jj].U
			sU[ifile] = (*pst_ptr[jfile]).s[jj].sU
		endfor
		;
		ppt_select_best, Q, sQ, U, sU, Qx, sQx, Ux, sUx, Px, sPx, PAx, sPAx
		;
		;	same test of SNR > 2.5 or sP < 0.5% and P < 15%, write
		;
		HK = (*pst_ptr[kfile]).s[kk].H_2mass - (*pst_ptr[kfile]).s[kk].K_2mass
		sHK = (sqrt( ((*pst_ptr[kfile]).s[kk].sK2mass^2) + ((*pst_ptr[kfile]).s[kk].sH2mass^2))) < 99.99
		;
		;if(((Px/sPx ge snr_limit or sPx le sp_limit) and (Px lt p_limit)) or save_all eq 1) then begin
		;
			this_str = STRING(iig,(*pst_ptr[kfile]).s[kk].RA_deg,(*pst_ptr[kfile]).s[kk].Dec_deg,$
				(*pst_ptr[kfile]).s[kk].H_mag,(*pst_ptr[kfile]).s[kk].sHmag,$
				Px,sPx,PAx,sPAx,Qx,sQx,Ux,sUx,ng,$
				(*pst_ptr[kfile]).s[kk].desig_2mass,(*pst_ptr[kfile]).s[kk].J_2mass,$
				(*pst_ptr[kfile]).s[kk].sJ2mass,(*pst_ptr[kfile]).s[kk].H_2mass,$
				(*pst_ptr[kfile]).s[kk].sH2mass,(*pst_ptr[kfile]).s[kk].K_2mass,$
				(*pst_ptr[kfile]).s[kk].sK2mass,HK,sHK,$
				(*pst_ptr[kfile]).s[kk].b36mag,$
				(*pst_ptr[kfile]).s[kk].e_b36mag,$
				(*pst_ptr[kfile]).s[kk].b45mag,$
				(*pst_ptr[kfile]).s[kk].e_b45mag,$
				(*pst_ptr[kfile]).s[kk].b58mag,$
				(*pst_ptr[kfile]).s[kk].e_b58mag,$
				(*pst_ptr[kfile]).s[kk].b80mag,$
				(*pst_ptr[kfile]).s[kk].e_b80mag,$
				format=fmt)
			printf, lu_out, this_str, format='(a)'
			nout++
			n_common++
		;endif else n2_reject++
	endelse

endfor
;
;	close output file
;
FREE_LUN, lu_out
PTR_FREE, pst_ptr[*]
;
zprint,Event,'Wrote data file with '+string(nout,format='(I)')+' entries'
;zprint,Event,'Rejected '+string(n1_reject,format='(I)')+' single stars with low S/N'
;zprint,Event,'Rejected '+string(n2_reject,format='(I)')+' matched stars with low S/N'
;
wid_id = WIDGET_INFO(Event.top, FIND_BY_UNAME="Text_Total_Stars")
WIDGET_CONTROL, wid_id,SET_VALUE=STRING(nout,format='(I)')
;
wid_id = WIDGET_INFO(Event.top, FIND_BY_UNAME="Text_Unique_Stars")
WIDGET_CONTROL, wid_id,SET_VALUE=STRING(n_unique,format='(I)')
;
wid_id = WIDGET_INFO(Event.top, FIND_BY_UNAME="Text_Common_Stars")
WIDGET_CONTROL, wid_id,SET_VALUE=STRING(n_common,format='(I)')
;
the_end:
;
end


