pro ppt_plot_image, Event, iplot
	;
	;	plots the indicated image in:
	;	iplot = 0 -  the Draw_Final_Plot window of Tab 4
	;	iplot = 1 -  a postscript file
	;
	WIDGET_CONTROL, Event.top, GET_UVALUE=PTR
	;
	no_title = 1 - (*PTR).plot_title_flag
	;
	;***** TBD - plot in RA, Dec space
	;
	;	for now, do in pixel space
	;
	ncol = SXPAR((*(*PTR).header_ptr),'NAXIS1')
	nrow = SXPAR((*(*PTR).header_ptr),'NAXIS2')
	;
	xr = [0, ncol]
	yr = [0, nrow]
	;
	plot, xr, yr, xr=xr, yr=yr, xs=1, ys=1, /nodata, $
		color=get_color(Event,'white'),/isotropic
	;
	;---------------------------------------------------------
	;
	;
	;	get header info
	;
	crpix1 = sxpar((*(*PTR).header_ptr), 'CRPIX1')
	crpix2 = sxpar((*(*PTR).header_ptr), 'CRPIX2')
	crval1 = sxpar((*(*PTR).header_ptr), 'CRVAL1')
	crval2 = sxpar((*(*PTR).header_ptr), 'CRVAL2')
	cd1_1 = sxpar((*(*PTR).header_ptr), 'CD1_1',count=count_cd11)
	if(count_cd11 eq 0) then begin
	   cd1_1 = sxpar((*(*PTR).header_ptr),'CDELT1')
	endif
	cd2_2 = sxpar((*(*PTR).header_ptr), 'CD2_2',count=count_cd22)
	if(count_cd22 eq 0) then begin
	  cd2_2 = sxpar((*(*PTR).header_ptr),'CDELT2')
	endif
	;
	cosdec = cos(crval2*!PI/180.0d0)
	;
	;	compute ra, dec ranges
	;
	ra0 = (crpix1 - 1)    * cd1_1/cosdec + crval1
	ra1 = (crpix1 - ncol) * cd1_1/cosdec + crval1
	;
	dec0 = (1 - crpix2)    * cd2_2 + crval2
	dec1 = (nrow - crpix2) * cd2_2 + crval2
	;
	if(dec1 lt dec0) then begin
		dec2 = dec1
		dec1 = dec0
		dec0 = dec2
	endif
	;
	;	compute difference in dec range
	;
	dec_range = abs(dec1 - dec0) * 60.0			; in arcmin
	pwr_dec_range = floor(alog(dec_range)/alog(2.)) 	; base 2 power index
	dec_step = 1.0 * (2.0^(pwr_dec_range-2))				; 2 arcmin for 10 arcmin FOV
	ndec = ceil((dec_range / dec_step) + 0.55)
	;
	;	compute difference in RA range
	;
	ra_range = abs(ra1 - ra0) * 60.0 / 15.0			; in min of time units
	pwr_ra_range = floor(alog(ra_range)/alog(2.))
	ra_step = (1.0/6.) * (2.0^(pwr_ra_range+1))		; 10s base size for 10 armin FOV
	nra = ceil((ra_range / ra_step) + 0.55)
	ra_step *= 60.0									; change to sec of time
;
	if(iplot eq 0) then begin
		plot_wid = WIDGET_INFO(Event.top, FIND_BY_UNAME='Draw_Final_Plot')
		win_geo = WIDGET_INFO(plot_wid, /GEOMETRY)		; fetch window geometry
		;
		WIDGET_CONTROL, plot_wid, GET_VALUE=win
		wset, win
		erase
;		SET_PLOT, this_device
;		Window, 20, xsize=700, ysize=700
		chsz = 2.0
		thick = 2
		(*PTR).chsz = chsz
		(*PTR).thick = thick
		ps_thick = 1.0				; extra thickness term for PS
		(*PTR).ps_thick=ps_thick
		;
		win_dx = win_geo.SCR_Xsize
		win_dy = win_geo.SCR_Ysize
		;
		!P.FONT=1
		Device, set_font='Times'
	endif
;
	if(iplot ne 0) then begin
		;
		SET_PLOT, 'PS'
		!P.FONT=1
		DEVICE, /TIMES, FONT_SIZE=13, /PORTRAIT, /ENCAPSUL, /COLOR, $
				XSIZE=24, YSIZE=22
		;
		DEVICE, FILENAME=(*PTR).ps_out
		chsz = 1.75
		thick=4
		ps_thick = 4.0
		(*PTR).ps_thick=ps_thick
		(*PTR).chsz = chsz
		(*PTR).thick = thick
		;
		win_dx = !D.X_Vsize
		win_dy = !D.Y_Vsize
	endif
	;
	this_image = PTR_NEW((*(*PTR).image_ptr))
	;
	vec = (*this_image)[0.4*ncol:0.6*ncol,0.4*nrow:0.6*nrow]
	vec = vec[WHERE(vec)]
	mfm = median_filtered_mean(vec)
	;
	;   do log scaling for values in excess of mean
	;
	(*this_image) -= mfm[0]
	ind_z = WHERE((*this_image) le 0.,count_z)
	;print, "number of pixels below 0 = ",count_z
	ind = WHERE((*this_image) gt 0.)
	(*this_image)[ind_z] = -0.2
	(*this_image)[ind] = -0.1 > alog10((*this_image)[ind])
	;
	offset = (*PTR).offset
	range = (*PTR).range
	;offset = 2.0	; log counts, was 1.5
	;range = 3.0		; log counts, was 4.5
	deep_scaled = bytscl((255 < (0 > ((*this_image)-offset) * 255.0 / range)),min=0,max=255,top=245)
	deep_scaled = 245B - deep_scaled
	deep_scaled += 10
	;
	;	scale so to keep sky scale true
	;
	dxy = win_dx < win_dy ; smaller of each
	;
	if(win_dx ge win_dy) then begin
		dx = dxy * float(ncol)/float(nrow)
		dy = win_dy
		dxoff = fix(0.5*(win_dx-win_dy))
		dyoff = 0
	endif else begin
		dy = dxy * float(nrow)/float(ncol)
		dx = win_dx
		dxoff = 0
		dyoff = fix(0.5*(win_dy-win_dx))
	endelse
	;
	xmar=[0.13,0.06]	; x margin as % to skip from left, % to skip from right
	ymar=[0.13,0.06]
	x0 = 0
	y0 = 0
	;
	position = [(x0+xmar[0])*dx,(y0+ymar[0])*dy,(x0+1.0-xmar[1])*dx,(y0+1.0-ymar[1])*dy]
	;
	position += [dxoff, dyoff, dxoff, dyoff]
	;
	xsize = (position[2] - position[0])
	ysize = (position[3] - position[1])
	xstart = position[0]
	ystart = position[1]
	;
;	print, 'position = ',position
	win_position = [position[0]/win_dx,position[1]/win_dy,position[2]/win_dx,position[3]/win_dy]
	;
;	print, 'position/win = ',win_position
	;
	if !D.Name eq 'PS' then $
	    TV, deep_scaled, XSize=xsize, YSize=ysize, xstart, ystart $
	else $
	    TV, CONGRID(deep_scaled, xsize, ysize), xstart, ystart
	;
	;	labels
	;
;	xtx = 'RA!DJ2000!N '
;	yty = 'Dec!DJ2000!N '
	;
	xtx = 'RA [J2000]'
	yty = 'Dec [J2000]'
	;
	;	tick at integer RA 10s values
	;
	rahms = sexig(ra1/15.0)		; 3 tuple
	;
	;	nearest next s of 10s
	;
	rahms[2] = floor(rahms[2] / 10.0) * 10.0
	xlab = strarr(nra)
	xval = dblarr(nra)
	for i=0,nra-1 do begin
		if(rahms[2] lt 0.0) then begin
			rahms[1] -= 1.0
			rahms[2] += 60.0
		endif
		hh = floor(rahms[0])
		mm = floor(rahms[1])
		ss = floor(rahms[2])
		;
		xlab[i] = STRING(hh,format='(I2.2)')+'!UH!N'+STRING(mm,format='(i2.2)')+$
					'!UM!N'+STRING(ss,format='(i2.2)')+'!US!N'
		xval[i] = 15.0*(rahms[0]+rahms[1]/60.0d0+rahms[2]/3600.0d0)
		rahms[2] -= ra_step
	endfor
	;
	ind_x = WHERE(xval le ra1 and xval ge ra0,nx)
	xlab = xlab[ind_x]
	xval = xval[ind_x]
	;
	;	dec at 2 arcmin intervals
	;
	dechms = sexig(dec0)
	if(dec0 lt 0.0) then decsign = -1.0d0 else decsign = 1.0d0
	dechms[0] = abs(dechms[0])
	;
	dechms[2] = 0.0 ; force to armin boundary
	dechms[1] -= 1.0
	if(dechms[1] lt 0.0) then begin
		dechms[0] -= 1.0
		dechms[1] += 60.0
	endif
	;
	;	arcmin symbol
	;
	this_min = "242B
	ch_min = STRING(this_min)
	;
	this_deg = "260B
	ch_deg = STRING(this_deg)
	;
	ylab = strarr(ndec)
	yval = dblarr(ndec)
	for i = 0, ndec-1 do begin
		if(dechms[1] gt 60.0) then begin
			dechms[1] -= 60.0
			dechms[0] += 1.0
		endif
		if(dechms[1] lt 0.0) then begin
			dechms[1] += 60.0
			dechms[0] -= 1.0
		endif
		dd = floor(dechms[0]*decsign)
		mm = floor(dechms[1])
		ss = floor(dechms[2])
		;
		ylab[i] = STRING(dd,format='(I3.2)')+'!9'+ch_deg+'!X'+$
				STRING(mm,format='(i2.2)')+'!9'+ch_min+'!X'
		yval[i] = decsign*(abs(dechms[0])+dechms[1]/60.0d0+dechms[2]/3600.0d0)
		if(dechms[0] lt 0.0) then yval[i] *= -1.0d0
		dechms[1] += dec_step*decsign
	endfor
	;
	ind_y = WHERE(yval ge dec0 and yval le dec1,ny)
	;stop
	ylab = ylab[ind_y]
	yval = yval[ind_y]
	;
	;stop
	;
	name = (*PTR).image_name
	;
	if(no_title eq 0) then begin
		plot, [ra1,ra0],[dec0,dec1], /nodata, /noerase, xr=[ra1,ra0], yr=[dec0,dec1], $
			xs = 1, ys = 1, charthick=thick, charsize=chsz, $ ; $ xtickinterval = 200, $
			; ytickinterval = 200,
			xtitle=xtx, ytitle=yty,$
			position=win_position, xthick=thick, ythick =thick, $
			xtickname=xlab,xtickv=xval, xticks=nx-1, xminor=5, $
			ytickname=ylab,ytickv=yval, yticks=ny-1, yminor=4, $
			title=name
	endif else begin
		;
		plot, [ra1,ra0],[dec0,dec1], /nodata, /noerase, xr=[ra1,ra0], yr=[dec0,dec1], $
			xs = 1, ys = 1, charthick=thick, charsize=chsz, $ ; $ xtickinterval = 200, $
			; ytickinterval = 200,
			xtitle=xtx, ytitle=yty,$
			position=win_position, xthick=thick, ythick =thick, $
			xtickname=xlab,xtickv=xval, xticks=nx-1, xminor=5, $
			ytickname=ylab,ytickv=yval, yticks=ny-1, yminor=4
	endelse
		;
;A = FINDGEN(9) * (!PI*2/8.)
;; Define the symbol to be a unit circle with 16 points,
;; and set the filled flag:
;USERSYM, COS(A), SIN(A), thick=2
	;
	;	grid lines
	;
	for i=0,nx-1 do oplot,[xval[i],xval[i]],[dec0,dec1],psym=-5,$
		symsize=0.001,linestyle=2,thick=1,color=get_color(event,'gray')
	for i=0,ny-1 do oplot,[ra1, ra0],[yval[i],yval[i]],psym=-5,$
		symsize=0.001,linestyle=2,thick=1,color=get_color(event,'gray')
	;
	;
	PTR_FREE, this_image
	;
;
;!P.MULTI = 0
;
end
